@@ -187,7 +187,8 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
         break;
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          if (!MagickMonitor(LoadImageText,y,image->rows,exception))
+          if (!MagickMonitorFormatted(y,image->rows,exception,
+                                      LoadImageText,image->filename))
             break;
     }
     image->is_grayscale=MagickTrue;
@@ -219,7 +220,8 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (!MagickMonitor(LoadImagesText,TellBlob(image),GetBlobSize(image),exception))
+        if (!MagickMonitorFormatted(TellBlob(image),GetBlobSize(image),exception,
+                                    LoadImagesText,image->filename))
           break;
       }
   } while (count != 0);
@@ -262,72 +264,80 @@ ModuleExport void RegisterGRAYImage(void)
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->raw=True;
-  entry->description=AcquireString("Raw gray samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw gray samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("R");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw red samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw red samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("C");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw cyan samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw cyan samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("G");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw green samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw green samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("M");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw magenta samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw magenta samples";
+  entry->module="GRAY";
+
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("B");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw blue samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw blue samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("Y");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw yellow samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw yellow samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("O");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw opacity samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw opacity samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
+
   entry=SetMagickInfo("K");
   entry->decoder=(DecoderHandler) ReadGRAYImage;
   entry->encoder=(EncoderHandler) WriteGRAYImage;
   entry->stealth=True;
   entry->raw=True;
-  entry->description=AcquireString("Raw black samples");
-  entry->module=AcquireString("GRAY");
+  entry->description="Raw black samples";
+  entry->module="GRAY";
   (void) RegisterMagickInfo(entry);
 }
 
@@ -462,14 +472,16 @@ static unsigned int WriteGRAYImage(const ImageInfo *image_info,Image *image)
       (void) WriteBlob(image,packet_size*image->columns,scanline);
       if (image->previous == (Image *) NULL)
         if (QuantumTick(y,image->rows))
-          if (!MagickMonitor(SaveImageText,y,image->rows,&image->exception))
+          if (!MagickMonitorFormatted(y,image->rows,&image->exception,
+                                      SaveImageText,image->filename))
             break;
     }
     MagickFreeMemory(scanline);
     if (image->next == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (!MagickMonitor(SaveImagesText,scene++,GetImageListLength(image),&image->exception))
+    if (!MagickMonitorFormatted(scene++,GetImageListLength(image),&image->exception,
+                                SaveImagesText,image->filename))
       break;
   } while (image_info->adjoin);
   if (image_info->adjoin)
