@@ -37,7 +37,7 @@
 #include "magick/studio.h"
 #include "magick/attribute.h"
 #include "magick/blob.h"
-#include "magick/cache.h"
+#include "magick/pixel_cache.h"
 #include "magick/color.h"
 #include "magick/constitute.h"
 #include "magick/magick.h"
@@ -87,14 +87,14 @@ typedef struct _PDBImage
     reserved_1,
     note;
 
-  short int
+  unsigned short int
     x_last,
     y_last;
 
   unsigned long
     reserved_2;
 
-  short int
+  unsigned short int
     x_anchor,
     y_anchor,
     width,
@@ -279,10 +279,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *pixels;
 
   unsigned int
+    bits_per_pixel,
     status;
 
   unsigned long
-    bits_per_pixel,
     packets;
 
   /*
@@ -413,12 +413,12 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
+        indexes=AccessMutableIndexes(image);
         for (x=0; x < ((long) image->columns-7); x+=8)
         {
           for (bit=0; bit < 8; bit++)
           {
-            index=(*p & (0x80 >> bit) ? 0x00 : 0x01);
+            index=(*p & (0x80U >> bit) ? 0x00U : 0x01U);
             indexes[x+bit]=index;
             *q++=image->colormap[index];
           }
@@ -427,7 +427,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          if (!MagickMonitor(LoadImageText,y,image->rows,exception))
+          if (!MagickMonitorFormatted(y,image->rows,exception,LoadImageText,
+                                      image->filename))
             break;
       }
       break;
@@ -442,7 +443,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
+        indexes=AccessMutableIndexes(image);
         for (x=0; x < (long) image->columns; x+=4)
         {
           index=(IndexPacket) (3-((*p >> 6) & 0x03));
@@ -466,7 +467,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          if (!MagickMonitor(LoadImageText,y,image->rows,exception))
+          if (!MagickMonitorFormatted(y,image->rows,exception,LoadImageText,
+                                      image->filename))
             break;
       }
       break;
@@ -481,7 +483,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
+        indexes=AccessMutableIndexes(image);
         for (x=0; x < (long) image->columns; x+=2)
         {
           index=(IndexPacket) (15-((*p >> 4) & 0x0f));
@@ -497,7 +499,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (!SyncImagePixels(image))
           break;
         if (QuantumTick(y,image->rows))
-          if (!MagickMonitor(LoadImageText,y,image->rows,exception))
+          if (!MagickMonitorFormatted(y,image->rows,exception,LoadImageText,
+                                      image->filename))
             break;
       }
       break;
@@ -537,7 +540,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               length<<=1;
               length+=MaxTextExtent;
-              MagickReallocMemory(comment,length+1);
+              MagickReallocMemory(char *,comment,length+1);
               if (comment == (char *) NULL)
                 break;
               p=comment+strlen(comment);
@@ -587,8 +590,8 @@ ModuleExport void RegisterPDBImage(void)
   entry->decoder=(DecoderHandler) ReadPDBImage;
   entry->encoder=(EncoderHandler) WritePDBImage;
   entry->magick=(MagickHandler) IsPDB;
-  entry->description=AcquireString("Palm Database ImageViewer Format");
-  entry->module=AcquireString("PDB");
+  entry->description="Palm Database ImageViewer Format";
+  entry->module="PDB";
   (void) RegisterMagickInfo(entry);
 }
 
@@ -649,11 +652,11 @@ ModuleExport void UnregisterPDBImage(void)
 static unsigned char *EncodeRLE(unsigned char *destination,
   unsigned char *source,unsigned int literal,unsigned int repeat)
 {
-  if (literal > 0)
+  if (literal != 0)
     *destination++=literal-1;
-  memcpy(destination,source,literal);
+  (void) memcpy(destination,source,literal);
   destination+=literal;
-  if (repeat > 0)
+  if (repeat != 0)
     {
       *destination++=0x80 | (repeat-1);
       *destination++=source[literal];
@@ -685,12 +688,12 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
     *scanline;
 
   unsigned int
+    bits_per_pixel,    
+    packet_size,
     status;
 
   unsigned long
-    bits_per_pixel,
     literal,
-    packet_size,
     packets,
     repeat;
 
@@ -707,13 +710,13 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == False)
     ThrowWriterException(FileOpenError,UnableToOpenFile,image);
-  TransformColorspace(image,RGBColorspace);
+  (void) TransformColorspace(image,RGBColorspace);
   bits_per_pixel=image->depth;
   if (GetImageType(image,&image->exception) == BilevelType)
     bits_per_pixel=1;
   if ((bits_per_pixel != 1) && (bits_per_pixel != 2))
     bits_per_pixel=4;
-  memset(pdb_info.name,0,32);
+  (void) memset(pdb_info.name,0,32);
   (void) strncpy(pdb_info.name,image_info->filename,32);
   pdb_info.attributes=0;
   pdb_info.version=0;
@@ -723,8 +726,8 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   pdb_info.modify_number=0;
   pdb_info.application_info=0;
   pdb_info.sort_info=0;
-  memcpy(pdb_info.type,"vIMG",4);
-  memcpy(pdb_info.id,"View",4);
+  (void) memcpy(pdb_info.type,"vIMG",4);
+  (void) memcpy(pdb_info.id,"View",4);
   pdb_info.seed=0;
   pdb_info.next_record=0;
   comment=GetImageAttribute(image,"comment");
@@ -747,9 +750,9 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   pdb_image.version=1;  /* RLE Compressed */
   switch(bits_per_pixel)
   {
-    case 1: pdb_image.type=(char) 0xff; break;  /* monochrome */
-    case 2: pdb_image.type=(char) 0x00; break;  /* 2 bit gray */
-    default: pdb_image.type=(char) 0x02;  /* 4 bit gray */
+    case 1: pdb_image.type=0xffU; break;  /* monochrome */
+    case 2: pdb_image.type=0x00U; break;  /* 2 bit gray */
+    default: pdb_image.type=0x02U;        /* 4 bit gray */
   }
   pdb_image.reserved_1=0;
   pdb_image.note=0;
@@ -770,10 +773,10 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   if (buffer == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitWarning,MemoryAllocationFailed,image);
   packet_size=image->depth > 8 ? 2: 1;
-  scanline=MagickAllocateMemory(unsigned char *,packet_size*image->columns);
+  scanline=MagickAllocateArray(unsigned char *,image->columns,packet_size);
   if (scanline == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitWarning,MemoryAllocationFailed,image);
-  TransformColorspace(image,RGBColorspace);
+  (void) TransformColorspace(image,RGBColorspace);
   /*
     Convert to GRAY raster scanline.
   */
@@ -786,7 +789,7 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   {
     if (!AcquireImagePixels(image,0,y,image->columns,1,&image->exception))
       break;
-    (void) PopImagePixels(image,GrayQuantum,scanline);
+    (void) ExportImagePixelArea(image,GrayQuantum,image->depth,scanline,0,0);
     for (x=0; x < pdb_image.width; x++)
     {
       if (x < (long) image->columns)
@@ -826,7 +829,7 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
               if (0x7f < literal)
                 {
                   q=EncodeRLE(q,buffer,(literal < 0x80 ? literal : 0x80),0);
-                  CloneMemory(buffer,buffer+literal+repeat,0x80);
+                  (void) memmove(buffer,buffer+literal+repeat,0x80);
                   literal-=0x80;
                 }
             }
@@ -835,7 +838,8 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
       }
     }
     if (QuantumTick(y,image->rows))
-      if (!MagickMonitor(SaveImageText,y,image->rows,&image->exception))
+      if (!MagickMonitorFormatted(y,image->rows,&image->exception,
+                                  SaveImageText,image->filename))
         break;
   }
   q=EncodeRLE(q,buffer,literal,repeat);
@@ -879,7 +883,7 @@ static unsigned int WritePDBImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlob(image,q-p,p);
   MagickFreeMemory(p);
   if (pdb_info.number_records > 1)
-    WriteBlobString(image,comment->value);
+    (void) WriteBlobString(image,comment->value);
   CloseBlob(image);
   return(True);
 }
