@@ -305,6 +305,9 @@ MagickExport Image *ConvolveImage(const Image *image,const unsigned int order,
   MagickPassFail
     status;
 
+  const MagickBool
+    matte=((image->matte) || (image->colorspace == CMYKColorspace));
+
   /*
     Initialize convolve image attributes.
   */
@@ -405,7 +408,7 @@ MagickExport Image *ConvolveImage(const Image *image,const unsigned int order,
 
     (void) memset(&zero,0,sizeof(DoublePixelPacket));
 #if defined(HAVE_OPENMP)
-#  pragma omp parallel for schedule(static,16) shared(row_count, status)
+#  pragma omp parallel for schedule(dynamic,4) shared(row_count, status)
 #endif
     for (y=0; y < (long) convolve_image->rows; y++)
       {
@@ -458,7 +461,8 @@ MagickExport Image *ConvolveImage(const Image *image,const unsigned int order,
                         pixel.red+=(*k)*r[u].red;
                         pixel.green+=(*k)*r[u].green;
                         pixel.blue+=(*k)*r[u].blue;
-                        pixel.opacity+=(*k)*r[u].opacity;
+                        if (matte)
+                          pixel.opacity+=(*k)*r[u].opacity;
                         k++;
                       }
                     r+=image->columns+width;
@@ -594,7 +598,7 @@ MagickExport Image *ImplodeImage(const Image *image,const double amount,
       row_count=0;
 
 #if defined(HAVE_OPENMP)
-#  pragma omp parallel for schedule(static,16) shared(row_count, status)
+#  pragma omp parallel for schedule(dynamic,4) shared(row_count, status)
 #endif
     for (y=0; y < (long) image->rows; y++)
       {
@@ -942,7 +946,7 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     Paint each row of the image.
   */
 #if defined(HAVE_OPENMP)
-#  pragma omp parallel for schedule(static,16) shared(row_count, status)
+#  pragma omp parallel for schedule(dynamic,4) shared(row_count, status)
 #endif
   for (y=0; y < (long) image->rows; y++)
     {
@@ -1476,7 +1480,7 @@ MagickExport Image *SwirlImage(const Image *image,double degrees,
       row_count=0;
 
 #if defined(HAVE_OPENMP)
-#  pragma omp parallel for schedule(static,16) shared(row_count, status)
+#  pragma omp parallel for schedule(dynamic,8) shared(row_count, status)
 #endif
     for (y=0; y < (long) image->rows; y++)
       {
@@ -1666,7 +1670,7 @@ MagickExport Image *WaveImage(const Image *image,const double amplitude,
       row_count=0;
 
 #if defined(HAVE_OPENMP)
-#  pragma omp parallel for schedule(static,16) shared(row_count, status)
+#  pragma omp parallel for schedule(dynamic,4) shared(row_count, status)
 #endif
     for (y=0; y < (long) wave_image->rows; y++)
       {
